#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class non_conformal_interface_numerics:
    fluent_name = ...
    command_names = ...

    def change_numerics(self, use_sided_area_vector: bool, use_nci_sided_area_vectors: bool, recrete: bool):
        """
        Enable modified non-conformal interface numerics.
        
        Parameters
        ----------
            use_sided_area_vector : bool
                'use_sided_area_vector' child.
            use_nci_sided_area_vectors : bool
                'use_nci_sided_area_vectors' child.
            recrete : bool
                'recrete' child.
        
        """

