#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class geometry:
    fluent_name = ...
    child_names = ...
    parts = ...
    command_names = ...

    def list_topology(self, ):
        """
        'list_topology' command.
        """

