#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class plot_write_sample:
    fluent_name = ...
    command_names = ...

    def plot_sample(self, loaded_samples: str, variable_to_sampled: str, weighting_var: str, correlation_var: str, read_fn: str, overwrite: bool):
        """
        'plot_sample' command.
        
        Parameters
        ----------
            loaded_samples : str
                'loaded_samples' child.
            variable_to_sampled : str
                'variable_to_sampled' child.
            weighting_var : str
                'weighting_var' child.
            correlation_var : str
                'correlation_var' child.
            read_fn : str
                'read_fn' child.
            overwrite : bool
                'overwrite' child.
        
        """

    def write_sample(self, loaded_samples: str, variable_to_sampled: str, weighting_var: str, correlation_var: str, read_fn: str, overwrite: bool):
        """
        'write_sample' command.
        
        Parameters
        ----------
            loaded_samples : str
                'loaded_samples' child.
            variable_to_sampled : str
                'variable_to_sampled' child.
            weighting_var : str
                'weighting_var' child.
            correlation_var : str
                'correlation_var' child.
            read_fn : str
                'read_fn' child.
            overwrite : bool
                'overwrite' child.
        
        """

