#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class materials:
    fluent_name = ...
    child_names = ...
    fluid = ...
    solid = ...
    mixture = ...
    inert_particle = ...
    droplet_particle = ...
    combusting_particle = ...
    particle_mixture = ...
    command_names = ...

    def list_materials(self, ):
        """
        'list_materials' command.
        """

    def copy_database_material_by_name(self, type: str, name: str):
        """
        'copy_database_material_by_name' command.
        
        Parameters
        ----------
            type : str
                'type' child.
            name : str
                'name' child.
        
        """

    def copy_database_material_by_formula(self, type: str, formula: str):
        """
        'copy_database_material_by_formula' command.
        
        Parameters
        ----------
            type : str
                'type' child.
            formula : str
                'formula' child.
        
        """

