#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class adapt:
    fluent_name = ...
    child_names = ...
    refinement_criteria = ...
    coarsening_criteria = ...
    manual_refinement_criteria = ...
    manual_coarsening_criteria = ...
    set = ...
    profile = ...
    free_hierarchy = ...
    multi_layer_refinement = ...
    geometry = ...
    command_names = ...

    def adapt_mesh(self, ):
        """
        Adapt the mesh based on set refinement/coarsening criterion.
        """

    def display_adaption_cells(self, ):
        """
        Display cells marked for refinement/coarsening.
        """

    def list_adaption_cells(self, ):
        """
        List the number of cells marked for refinement/coarsening.
        """

