#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class statistics:
    fluent_name = ...
    child_names = ...
    reset_statistics = ...
    command_names = ...

    def statistics_controls(self, method: int, samp_time_period: Union[float, str], samp_time_steps: int, avg_time_period: Union[float, str], avg_time_steps: int):
        """
        'statistics_controls' command.
        
        Parameters
        ----------
            method : int
                'method' child.
            samp_time_period : real
                'samp_time_period' child.
            samp_time_steps : int
                'samp_time_steps' child.
            avg_time_period : real
                'avg_time_period' child.
            avg_time_steps : int
                'avg_time_steps' child.
        
        """

