#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class disk_id:
    fluent_name = ...
    child_names = ...
    embedded_face_zone = ...
    floating_surface_name = ...
    command_names = ...

    def create_floating_disk(self, ):
        """
        'create_floating_disk' command.
        """

