#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class surface_mesh:
    fluent_name = ...
    command_names = ...

    def delete(self, surface: str):
        """
        Delete surface mesh.
        
        Parameters
        ----------
            surface : str
                'surface' child.
        
        """

    def display(self, ):
        """
        Display surface meshes.
        """

    def read(self, filename: str, unit: str):
        """
        Read surface meshes.
        
        Parameters
        ----------
            filename : str
                'filename' child.
            unit : str
                'unit' child.
        
        """

