#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class moving_mesh_velocity:
    fluent_name = ...
    command_names = ...

    def list_properties(self, object_at: int):
        """
        'list_properties' command.
        
        Parameters
        ----------
            object_at : int
                'object_at' child.
        
        """

    <class 'ansys.fluent.core.solver.flobject.child_object_type'> = ...
